@@ -6,9 +6,16 @@
 #' Bar charts for categorical data with statistical details included in the plot
 #' as a subtitle.
 #'
+#' @section Summary of graphics:
+#'
+#' ```{r child="man/rmd-fragments/ggbarstats_graphics.Rmd"}
+#' ```
+#'
 #' @inheritParams ggpiestats
 #' @inheritParams ggbetweenstats
 #'
+#' @inheritSection statsExpressions::contingency_table Contingency table analyses
+#'
 #' @seealso \code{\link{grouped_ggbarstats}}, \code{\link{ggpiestats}},
 #'  \code{\link{grouped_ggpiestats}}
 #'
@@ -18,10 +25,15 @@
 #' \donttest{
 #' # for reproducibility
 #' set.seed(123)
-#' library(ggstatsplot)
 #'
-#' # association test (or contingency table analysis)
-#' ggbarstats(mtcars, x = vs, y = cyl)
+#' # creating a plot
+#' p <- ggbarstats(mtcars, x = vs, y = cyl)
+#'
+#' # looking at the plot
+#' p
+#'
+#' # extracting details from statistical tests
+#' extract_stats(p)
 #' }
 #' @export
 ggbarstats <- function(data,
@@ -52,7 +64,6 @@ ggbarstats <- function(data,
                        package = "RColorBrewer",
                        palette = "Dark2",
                        ggplot.component = NULL,
-                       output = "plot",
                        ...) {
   # data frame ------------------------------------------
 
@@ -65,7 +76,7 @@ ggbarstats <- function(data,
   # creating a data frame
   data %<>%
     select({{ x }}, {{ y }}, .counts = {{ counts }}) %>%
-    tidyr::drop_na(.)
+    tidyr::drop_na()
 
   # untable the data frame based on the count for each observation
   if (".counts" %in% names(data)) data %<>% tidyr::uncount(weights = .counts)
@@ -95,23 +106,15 @@ ggbarstats <- function(data,
     )
 
     subtitle_df <- .eval_f(contingency_table, !!!.f.args, type = type)
-    if (!is.null(subtitle_df)) subtitle <- subtitle_df$expression[[1]]
+    if (!is.null(subtitle_df)) subtitle <- subtitle_df$expression[[1L]]
 
     # preparing Bayes Factor caption
     if (type != "bayes" && bf.message && isFALSE(paired)) {
       caption_df <- .eval_f(contingency_table, !!!.f.args, type = "bayes")
-      if (!is.null(caption_df)) caption <- caption_df$expression[[1]]
+      if (!is.null(caption_df)) caption <- caption_df$expression[[1L]]
     }
   }
 
-  # return early if anything other than plot
-  if (output != "plot") {
-    return(switch(output,
-      "caption" = caption,
-      subtitle
-    ))
-  }
-
   # plot ------------------------------------------
 
   # data frame with summary labels
@@ -200,7 +203,7 @@ ggbarstats <- function(data,
 #' \donttest{
 #' # for reproducibility
 #' set.seed(123)
-#' library(ggstatsplot)
+#'
 #' library(dplyr, warn.conflicts = FALSE)
 #'
 #' # let's create a smaller data frame
@@ -222,7 +225,6 @@ ggbarstats <- function(data,
 grouped_ggbarstats <- function(data,
                                ...,
                                grouping.var,
-                               output = "plot",
                                plotgrid.args = list(),
                                annotation.args = list()) {
   # creating a data frame
@@ -230,13 +232,10 @@ grouped_ggbarstats <- function(data,
 
   # creating a list of return objects
   p_ls <- purrr::pmap(
-    .l = list(data = data, title = names(data), output = output),
+    .l = list(data = data, title = names(data)),
     .f = ggstatsplot::ggbarstats,
     ...
   )
 
-  # combining the list of plots into a single plot
-  if (output == "plot") p_ls <- combine_plots(p_ls, plotgrid.args, annotation.args)
-
-  p_ls
+  combine_plots(p_ls, plotgrid.args, annotation.args)
 }
