@@ -19,30 +19,20 @@
 #' # adding labels
 #' ggstatsplot:::.histo_labeller(
 #'   plot = p,
-#'   x = mtcars$wt
+#'   x = mtcars$wt,
+#'   centrality.line.args = list(color = "blue", linewidth = 1, linetype = "dashed"),
 #' )
 #' }
 #'
 #' @keywords internal
 #' @noRd
-.histo_labeller <- function(plot,
-                            x,
-                            centrality.line.args = list(
-                              color = "blue",
-                              size = 1,
-                              linetype = "dashed"
-                            ),
-                            ...) {
+.histo_labeller <- function(plot, x, centrality.line.args, ...) {
   # compute centrality measure (with a temporary data frame)
   df_central <- suppressWarnings(centrality_description(tibble(.x = ".x", "var" = x), .x, var, ...))
 
   # adding a vertical line corresponding to centrality parameter
   plot +
-    exec(
-      geom_vline,
-      xintercept = df_central$var,
-      !!!centrality.line.args
-    ) +
+    exec(geom_vline, xintercept = df_central$var, !!!centrality.line.args) +
     scale_x_continuous(
       sec.axis = sec_axis(
         trans = ~.,
