@@ -1,22 +1,19 @@
-# entire dataset ------------------------------------------------
+skip_if(getRversion() < "4.1")
+skip_if_not_installed("ggcorrplot")
 
 test_that(
   desc = "checking ggcorrmat with entier dataset",
   code = {
-    skip_if(getRversion() < "4.1")
-
-    skip_if_not_installed("ggcorrplot")
-
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "parametric correlation - without NAs",
-      fig = ggcorrmat(data = anscombe, type = "p")
+      fig = ggcorrmat(anscombe, type = "p")
     )
 
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "non-parametric correlation - with NAs",
-      fig = ggcorrmat(data = ggplot2::msleep, type = "np")
+      fig = ggcorrmat(ggplot2::msleep, type = "np")
     )
   }
 )
@@ -38,10 +35,6 @@ test_that(
 test_that(
   desc = "ggcorrmat works as expected with changed defaults",
   code = {
-    skip_if(getRversion() < "4.1")
-
-    skip_if_not_installed("ggcorrplot")
-
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "changing aesthetic defaults",
@@ -54,7 +47,7 @@ test_that(
         matrix.type = "full",
         p.adjust.method = "fdr",
         colors = NULL,
-        k = 4,
+        k = 4L,
         ggcorrplot.args = list(
           lab_col = "white",
           pch.col = "white"
@@ -99,3 +92,60 @@ test_that(
     )))
   }
 )
+
+# grouped_ggcorrmat output: plot ---------------------------------------------------------------
+
+skip_if_not_installed("ggcorrplot")
+
+test_that(
+  desc = "grouped_ggcorrmat plots are as expected",
+  code = {
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "without NAs",
+      fig = grouped_ggcorrmat(
+        iris,
+        grouping.var = Species,
+        cor.vars = Sepal.Length:Petal.Length
+      )
+    )
+
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "with NAs",
+      fig = grouped_ggcorrmat(
+        data = dplyr::select(ggplot2::msleep, dplyr::matches("sleep|awake|vore")),
+        grouping.var = vore,
+      )
+    )
+  }
+)
+
+# expected warnings -------------------------------------------
+
+test_that(
+  desc = "grouped_ggcorrmat produces error when grouping isn't specified",
+  code = {
+    expect_snapshot_error(grouped_ggcorrmat(iris))
+  }
+)
+
+# output: data frame ---------------------------------------------------------------
+
+test_that(
+  desc = "grouped_ggcorrmat returns expected data frame",
+  code = {
+    options(tibble.width = Inf)
+
+    # tidy data frame
+    df <- grouped_ggcorrmat(
+      data = dplyr::select(ggplot2::msleep, dplyr::matches("sleep|awake|vore")),
+      grouping.var = vore,
+      type = "r",
+      output = "data"
+    )
+
+    set.seed(123)
+    expect_snapshot(df)
+  }
+)
