@@ -1,3 +1,5 @@
+skip_if(getRversion() < "4.1")
+
 # data for paired tests
 set.seed(123)
 survey_data <- dplyr::tibble(
@@ -12,15 +14,11 @@ survey_data_NA <- dplyr::tibble(
   `Counts` = c(794L, 150L, NA_integer_, 570L)
 )
 
-
 # checking default outputs -----------------------------------------
 
 test_that(
   desc = "checking default outputs",
   code = {
-    skip_if(getRversion() < "4.1")
-
-
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "checking one-way table - without NA",
@@ -73,9 +71,6 @@ test_that(
 test_that(
   desc = "changing labels and aesthetics",
   code = {
-    skip_if(getRversion() < "4.1")
-
-
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "checking percentage labels",
@@ -174,8 +169,6 @@ test_that(
 test_that(
   desc = "edge cases",
   code = {
-    skip_if(getRversion() < "4.1")
-
     # dropped level dataset
     mtcars_small <- dplyr::filter(mtcars, am == "0")
 
@@ -204,18 +197,91 @@ test_that(
       data = ggplot2::msleep,
       x = conservation,
       y = vore,
-      k = 4,
-      output = "subtitle"
-    )
+      k = 4L
+    ) %>%
+      extract_subtitle()
 
     set.seed(123)
     stats_output <- suppressWarnings(contingency_table(
       data = ggplot2::msleep,
       x = conservation,
       y = vore,
-      k = 4
-    ))$expression[[1]]
+      k = 4L
+    ))$expression[[1L]]
 
     expect_equal(p_sub, stats_output)
   }
 )
+
+# grouped_ggpiestats works as expected ---------------------
+
+test_that(
+  desc = "grouped_ggpiestats produces error when grouping variable not provided",
+  code = {
+    expect_snapshot_error(grouped_ggpiestats(mtcars, x = cyl))
+  }
+)
+
+test_that(
+  desc = "grouped_ggpiestats works",
+  code = {
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "grouped_ggpiestats with one-way table",
+      fig = grouped_ggpiestats(
+        data = mtcars,
+        grouping.var = am,
+        x = cyl
+      )
+    )
+
+    # creating a smaller data frame
+    mpg_short <- ggplot2::mpg %>%
+      dplyr::filter(
+        drv %in% c("4", "f"),
+        class %in% c("suv", "midsize"),
+        trans %in% c("auto(l4)", "auto(l5)")
+      )
+
+    # when arguments are entered as bare expressions
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "grouped_ggpiestats with two-way table",
+      fig = grouped_ggpiestats(
+        data = mpg_short,
+        x = cyl,
+        y = class,
+        grouping.var = drv,
+        label.repel = TRUE
+      )
+    )
+  }
+)
+
+# grouped_ggpiestats edge cases --------------------
+
+test_that(
+  desc = "edge case behavior",
+  code = {
+    df <- data.frame(
+      dataset = c("a", "b", "c", "c", "c", "c"),
+      measurement = c("old", "old", "old", "old", "new", "new"),
+      flag = c("no", "no", "yes", "no", "yes", "no"),
+      count = c(6, 8, 8, 62, 6, 33)
+    )
+
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "common legend when levels are dropped",
+      fig = grouped_ggpiestats(
+        data = df,
+        x = measurement,
+        y = flag,
+        grouping.var = dataset,
+        counts = count,
+        results.subtitle = FALSE,
+        proportion.test = FALSE
+      )
+    )
+  }
+)
