@@ -1,19 +1,18 @@
 # pairwise comparisons testing is done `test-pairwise_ggsignif.R`
 
+skip_if(getRversion() < "4.1")
+skip_if_not_installed("PMCMRplus")
+skip_if_not_installed("afex")
+skip_if_not_installed("WRS2")
+
 # data
-data_bugs_2 <- dplyr::filter(bugs_long, subject <= 30, condition %in% c("HDLF", "HDHF"))
+data_bugs_2 <- dplyr::filter(bugs_long, subject <= 30L, condition %in% c("HDLF", "HDHF"))
 
 # defaults plots ---------------------------------
 
 test_that(
   desc = "defaults plots",
   code = {
-    skip_if(getRversion() < "4.1")
-
-    skip_if_not_installed("PMCMRplus")
-    skip_if_not_installed("afex")
-    skip_if_not_installed("WRS2")
-
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "defaults plots - two groups",
@@ -54,12 +53,6 @@ test_that(
 test_that(
   desc = "aesthetic modifications work",
   code = {
-    skip_if(getRversion() < "4.1")
-
-    skip_if_not_installed("PMCMRplus")
-    skip_if_not_installed("afex")
-    skip_if_not_installed("WRS2")
-
     set.seed(123)
     vdiffr::expect_doppelganger(
       title = "ggplot2 commands work",
@@ -88,3 +81,40 @@ test_that(
     )
   }
 )
+
+# outlier labeling works --------------------------------------------------
+
+test_that(
+  desc = "default plotting as expected",
+  code = {
+    # expect error when no grouping.var is specified
+    expect_snapshot_error(grouped_ggbetweenstats(bugs_long, x = condition, y = desire))
+
+    # outlier tagging is not required
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "default plots",
+      fig = grouped_ggwithinstats(
+        data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+        x = condition,
+        y = desire,
+        grouping.var = gender,
+        results.subtitle = FALSE
+      )
+    )
+
+    set.seed(123)
+    vdiffr::expect_doppelganger(
+      title = "outlier tagging and themes work",
+      fig = grouped_ggwithinstats(
+        data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+        x = condition,
+        y = desire,
+        grouping.var = gender,
+        ggtheme = ggplot2::theme_linedraw(),
+        results.subtitle = FALSE,
+        outlier.tagging = TRUE
+      )
+    )
+  }
+)
